@@ -1,8 +1,10 @@
-use strict;
-use warnings;
-
 package MooseX::MethodAttributes;
-our $VERSION = '0.20';
+BEGIN {
+  $MooseX::MethodAttributes::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $MooseX::MethodAttributes::VERSION = '0.21';
+}
 # ABSTRACT: code attribute introspection
 
 use Moose ();
@@ -48,17 +50,12 @@ sub init_meta {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
 
 MooseX::MethodAttributes - code attribute introspection
 
-=head1 VERSION
-
-version 0.20
-
 =head1 SYNOPSIS
 
     package MyClass;
@@ -75,13 +72,7 @@ version 0.20
 This module allows code attributes of methods to be introspected using Moose
 meta method objects.
 
-=begin Pod::Coverage
-
-init_meta
-
-=end Pod::Coverage
-
-
+=for Pod::Coverage init_meta
 
 =head1 AUTHORS
 
@@ -95,6 +86,5 @@ This software is copyright (c) 2010 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
